==> request-tracker4_4.4.6+dfsg.orig-third-party-source.tar.gz: rt-4.4.6/devel/third-party/ckeditor-src/plugins/table/lang/nb.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'table', 'nb', {
	border: 'Rammestørrelse',
	caption: 'Tittel',
	cell: {
		menu: 'Celle',
		insertBefore: 'Sett inn celle før',
		insertAfter: 'Sett inn celle etter',
		deleteCell: 'Slett celler',
		merge: 'Slå sammen celler',
		mergeRight: 'Slå sammen høyre',
		mergeDown: 'Slå sammen ned',
		splitHorizontal: 'Del celle horisontalt',
		splitVertical: 'Del celle vertikalt',
		title: 'Celleegenskaper',
		cellType: 'Celletype',
		rowSpan: 'Radspenn',
		colSpan: 'Kolonnespenn',
		wordWrap: 'Tekstbrytning',
		hAlign: 'Horisontal justering',
		vAlign: 'Vertikal justering',
		alignBaseline: 'Grunnlinje',
		bgColor: 'Bakgrunnsfarge',
		borderColor: 'Rammefarge',
		data: 'Data',
		header: 'Overskrift',
		yes: 'Ja',
		no: 'Nei',
		invalidWidth: 'Cellebredde må være et tall.',
		invalidHeight: 'Cellehøyde må være et tall.',
		invalidRowSpan: 'Radspenn må være et heltall.',
		invalidColSpan: 'Kolonnespenn må være et heltall.',
		chooseColor: 'Velg'
	},
	cellPad: 'Cellepolstring',
	cellSpace: 'Cellemarg',
	column: {
		menu: 'Kolonne',
		insertBefore: 'Sett inn kolonne før',
		insertAfter: 'Sett inn kolonne etter',
		deleteColumn: 'Slett kolonner'
	},
	columns: 'Kolonner',
	deleteTable: 'Slett tabell',
	headers: 'Overskrifter',
	headersBoth: 'Begge',
	headersColumn: 'Første kolonne',
	headersNone: 'Ingen',
	headersRow: 'Første rad',
	invalidBorder: 'Rammestørrelse må være et tall.',
	invalidCellPadding: 'Cellepolstring må være et positivt tall.',
	invalidCellSpacing: 'Cellemarg må være et positivt tall.',
	invalidCols: 'Antall kolonner må være et tall større enn 0.',
	invalidHeight: 'Tabellhøyde må være et tall.',
	invalidRows: 'Antall rader må være et tall større enn 0.',
	invalidWidth: 'Tabellbredde må være et tall.',
	menu: 'Egenskaper for tabell',
	row: {
		menu: 'Rader',
		insertBefore: 'Sett inn rad før',
		insertAfter: 'Sett inn rad etter',
		deleteRow: 'Slett rader'
	},
	rows: 'Rader',
	summary: 'Sammendrag',
	title: 'Egenskaper for tabell',
	toolbar: 'Tabell',
	widthPc: 'prosent',
	widthPx: 'piksler',
	widthUnit: 'Bredde-enhet'
} );

==> request-tracker5_5.0.7+dfsg.orig-third-party-source.tar.gz: rt-5.0.7/devel/third-party/ckeditor-src/plugins/table/lang/nb.js <==
/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'nb', {
	border: 'Rammestørrelse',
	caption: 'Tittel',
	cell: {
		menu: 'Celle',
		insertBefore: 'Sett inn celle før',
		insertAfter: 'Sett inn celle etter',
		deleteCell: 'Slett celler',
		merge: 'Slå sammen celler',
		mergeRight: 'Slå sammen høyre',
		mergeDown: 'Slå sammen ned',
		splitHorizontal: 'Del celle horisontalt',
		splitVertical: 'Del celle vertikalt',
		title: 'Celleegenskaper',
		cellType: 'Celletype',
		rowSpan: 'Radspenn',
		colSpan: 'Kolonnespenn',
		wordWrap: 'Tekstbrytning',
		hAlign: 'Horisontal justering',
		vAlign: 'Vertikal justering',
		alignBaseline: 'Grunnlinje',
		bgColor: 'Bakgrunnsfarge',
		borderColor: 'Rammefarge',
		data: 'Data',
		header: 'Overskrift',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Ja',
		no: 'Nei',
		invalidWidth: 'Cellebredde må være et tall.',
		invalidHeight: 'Cellehøyde må være et tall.',
		invalidRowSpan: 'Radspenn må være et heltall.',
		invalidColSpan: 'Kolonnespenn må være et heltall.',
		chooseColor: 'Velg'
	},
	cellPad: 'Cellepolstring',
	cellSpace: 'Cellemarg',
	column: {
		menu: 'Kolonne',
		insertBefore: 'Sett inn kolonne før',
		insertAfter: 'Sett inn kolonne etter',
		deleteColumn: 'Slett kolonner'
	},
	columns: 'Kolonner',
	deleteTable: 'Slett tabell',
	headers: 'Overskrifter',
	headersBoth: 'Begge',
	headersColumn: 'Første kolonne',
	headersNone: 'Ingen',
	headersRow: 'Første rad',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Rammestørrelse må være et tall.',
	invalidCellPadding: 'Cellepolstring må være et positivt tall.',
	invalidCellSpacing: 'Cellemarg må være et positivt tall.',
	invalidCols: 'Antall kolonner må være et tall større enn 0.',
	invalidHeight: 'Tabellhøyde må være et tall.',
	invalidRows: 'Antall rader må være et tall større enn 0.',
	invalidWidth: 'Tabellbredde må være et tall.',
	menu: 'Egenskaper for tabell',
	row: {
		menu: 'Rader',
		insertBefore: 'Sett inn rad før',
		insertAfter: 'Sett inn rad etter',
		deleteRow: 'Slett rader'
	},
	rows: 'Rader',
	summary: 'Sammendrag',
	title: 'Egenskaper for tabell',
	toolbar: 'Tabell',
	widthPc: 'prosent',
	widthPx: 'piksler',
	widthUnit: 'Bredde-enhet'
} );
